@@ -27,7 +27,7 @@ import pywebsite.sqlitepickle
 import sys
 try:
     from .base import NewsletterSend, Newsletter
-except ValueError:
+except ImportError:
     # a hack to put the newsletter package in the path.
     sys.path.append(os.path.join("..", ".."))
     from newsletter.base import NewsletterSend, Newsletter
@@ -838,8 +838,7 @@ def make_new_install(dst_directory):
 
 
 
-if __name__ == "__main__":
-
+def main():
     from optparse import OptionParser
 
     parser = OptionParser()
@@ -932,3 +931,7 @@ if __name__ == "__main__":
 
         cherrypy.engine.start()
         cherrypy.engine.block()
+
+
+if __name__ == "__main__":
+    main()
